==> nebula-core-1.2.3.10-Release-sources.jar: com/bizunited/platform/core/service/DynamicTaskSchedulerLogService.java <==
package com.bizunited.platform.core.service;

import java.lang.String;
import java.util.Set;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import com.bizunited.platform.core.entity.DynamicTaskSchedulerLogEntity;

/**
 * DynamicTaskSchedulerLogEntity业务模型的服务层接口定义
 * @author yinwenjie
 */
public interface DynamicTaskSchedulerLogService { 
  /**
   * 创建一个新的DynamicTaskSchedulerLogEntity模型对象（包括了可能的第三方系统调用、复杂逻辑处理等）
   */
  public DynamicTaskSchedulerLogEntity create(DynamicTaskSchedulerLogEntity dynamicTaskSchedulerLogEntity);
  /**
   * 创建一个新的StudentEntity模型对象
   * 该代码由satrun骨架生成，默认不包括任何可能第三方系统调用、任何复杂逻辑处理等，主要应用场景为前端表单数据的暂存功能</br>
   * 该方法与本接口中的updateFrom方法呼应
   */
  public DynamicTaskSchedulerLogEntity createForm(DynamicTaskSchedulerLogEntity dynamicTaskSchedulerLogEntity);
  /**
   * 更新一个已有的DynamicTaskSchedulerLogEntity模型对象，其主键属性必须有值(1.1.4-release版本调整)。
   * 这个方法实际上一共分为三个步骤（默认）：</br>
   * 1、调用updateValidation方法完成表单数据更新前的验证</br>
   * 2、调用updateForm方法完成表单数据的更新</br>
   * 3、完成开发人员自行在本update方法中书写的，进行第三方系统调用（或特殊处理过程）的执行。</br>
   * 这样做的目的，实际上是为了保证updateForm方法中纯粹是处理表单数据的，在数据恢复表单引擎默认调用updateForm方法时，不会影响任何第三方业务数据
   * （当然，如果系统有特别要求，可由开发人员自行完成代码逻辑调整）
   */
  public DynamicTaskSchedulerLogEntity update(DynamicTaskSchedulerLogEntity dynamicTaskSchedulerLogEntity);
  /**
   * 该方法只用于处理业务表单信息，包括了主业务模型、其下的关联模型、分组信息和明细细信息等
   * 该方法非常重要，因为如果进行静态表单的数据恢复，那么表单引擎将默认调用主业务模型（服务层）的这个方法。</br>
   * 这样一来保证了数据恢复时，不会涉及任何第三方系统的调用（当然，如果开发人员需要涉及的，可以自行进行修改）
   */
  public DynamicTaskSchedulerLogEntity updateForm(DynamicTaskSchedulerLogEntity dynamicTaskSchedulerLogEntity);
  /**
   * 按照关联的 对应的动态日志进行详情查询（包括关联信息）
   * @param dynamicTaskScheduler 关联的 对应的动态日志
   */
  public Set<DynamicTaskSchedulerLogEntity> findDetailsByDynamicTaskScheduler(String dynamicTaskScheduler);
  /**
   * 按照主键进行详情查询（包括关联信息）
   * @param id 主键
   */
  public DynamicTaskSchedulerLogEntity findDetailsById(String id);
  /**
   * -该方法用于按照分页标准，对动态任务日志列表进行查询，并按照开始执行时间进行倒序排列
   * @param pageable 分页信息
   * @param taskId 任务ID编号（必须传入）
   * @param success 是否执行成功
   * @param logtime 执行日志的开始执行时间
   */
  Page<DynamicTaskSchedulerLogEntity> findByConditions(Pageable pageable, String taskId , Boolean success , String logtime);
  /**
   * 按照DynamicTaskSchedulerLogEntity的主键编号，查询指定的数据信息（不包括任何关联信息）
   * @param id 主键
   * */
  public DynamicTaskSchedulerLogEntity findById(String id);
  /**
   *  按照主键进行信息的真删除 
   * @param id 主键 
   */
  public void deleteById(String id);
}

==> nebula-core-2.0.2.11-Release-sources.jar: com/bizunited/platform/core/service/DynamicTaskSchedulerLogService.java <==
package com.bizunited.platform.core.service;

import java.util.Set;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;

import com.bizunited.platform.core.entity.DynamicTaskSchedulerLogEntity;

/**
 * DynamicTaskSchedulerLogEntity业务模型的服务层接口定义
 * @author yinwenjie
 */
public interface DynamicTaskSchedulerLogService { 
  /**
   * 创建一个新的DynamicTaskSchedulerLogEntity模型对象（包括了可能的第三方系统调用、复杂逻辑处理等）
   */
  public DynamicTaskSchedulerLogEntity create(DynamicTaskSchedulerLogEntity dynamicTaskSchedulerLogEntity);
  /**
   * 创建一个新的StudentEntity模型对象
   * 该代码由satrun骨架生成，默认不包括任何可能第三方系统调用、任何复杂逻辑处理等，主要应用场景为前端表单数据的暂存功能</br>
   * 该方法与本接口中的updateFrom方法呼应
   */
  public DynamicTaskSchedulerLogEntity createForm(DynamicTaskSchedulerLogEntity dynamicTaskSchedulerLogEntity);
  /**
   * 更新一个已有的DynamicTaskSchedulerLogEntity模型对象，其主键属性必须有值(1.1.4-release版本调整)。
   * 这个方法实际上一共分为三个步骤（默认）：</br>
   * 1、调用updateValidation方法完成表单数据更新前的验证</br>
   * 2、调用updateForm方法完成表单数据的更新</br>
   * 3、完成开发人员自行在本update方法中书写的，进行第三方系统调用（或特殊处理过程）的执行。</br>
   * 这样做的目的，实际上是为了保证updateForm方法中纯粹是处理表单数据的，在数据恢复表单引擎默认调用updateForm方法时，不会影响任何第三方业务数据
   * （当然，如果系统有特别要求，可由开发人员自行完成代码逻辑调整）
   */
  public DynamicTaskSchedulerLogEntity update(DynamicTaskSchedulerLogEntity dynamicTaskSchedulerLogEntity);
  /**
   * 该方法只用于处理业务表单信息，包括了主业务模型、其下的关联模型、分组信息和明细细信息等
   * 该方法非常重要，因为如果进行静态表单的数据恢复，那么表单引擎将默认调用主业务模型（服务层）的这个方法。</br>
   * 这样一来保证了数据恢复时，不会涉及任何第三方系统的调用（当然，如果开发人员需要涉及的，可以自行进行修改）
   */
  public DynamicTaskSchedulerLogEntity updateForm(DynamicTaskSchedulerLogEntity dynamicTaskSchedulerLogEntity);
  /**
   * 按照关联的 对应的动态日志进行详情查询（包括关联信息）
   * @param dynamicTaskScheduler 关联的 对应的动态日志
   */
  public Set<DynamicTaskSchedulerLogEntity> findDetailsByDynamicTaskScheduler(String dynamicTaskScheduler);
  /**
   * 按照主键进行详情查询（包括关联信息）
   * @param id 主键
   */
  public DynamicTaskSchedulerLogEntity findDetailsById(String id);
  /**
   * -该方法用于按照分页标准，对动态任务日志列表进行查询，并按照开始执行时间进行倒序排列
   * @param pageable 分页信息
   * @param taskId 任务ID编号（必须传入）
   * @param success 是否执行成功
   * @param logtime 执行日志的开始执行时间
   */
  Page<DynamicTaskSchedulerLogEntity> findByConditions(Pageable pageable, String taskId , Boolean success , String logtime);
  /**
   * 按照DynamicTaskSchedulerLogEntity的主键编号，查询指定的数据信息（不包括任何关联信息）
   * @param id 主键
   * */
  public DynamicTaskSchedulerLogEntity findById(String id);
  /**
   *  按照主键进行信息的真删除 
   * @param id 主键 
   */
  public void deleteById(String id);
  /**
   * 按照指定的动态任务数据库编码，真删除其下所有的日志信息
   */
  public void deleteByDynamicTaskSchedulerId(String dynamicTaskSchedulerId);
}
